% This is an empy configuration-file for slrn. This version of the file is
% only meant for system-wide preferences. It is left empty by the installation,
% to let slrn's default settings be used.
%
% If you to include options in this file, take a look at the manpage for slrn
% or at /usr/share/doc/slrn/examples/slrn.rc.gz
